__author__ = 'Frank'

# pip install numpy /or/ pip2 install numpy /or/ pip3 install numpy

import ctypes as C
import numpy as np
import sys  # sys.exit(1), sys.stdout.write
import time
import builtins

CHASE_VERSION = "64bit"

try:
    chase_dll_path = r'/home/frank/Documents/temp/dax22_Library/libdax22_64.so'
    chaseDLL = C.CDLL(chase_dll_path)

except:
    print("Warning could not load Chase AWG dll, check that dll located at '%s'" % chase_dll_path)

addr = 1

# ------------------------------------------
# Get Number of Cards (exit if 0)
# ------------------------------------------
x = chaseDLL.DAx22000_GetNumCards()

if x == 0:
    print('No boards found.\r')
    sys.exit(1);
else:
    print('GetNumCards() = ' + str(x) + '\r\n')

# ------------------------------------------
# Open DAx22000 API Driver
# ------------------------------------------
x = chaseDLL.DAx22000_Open(C.c_int32(addr))

print('Open = ' + str(x) + '\r\n')

if x != 0:
    print('Cannot open DAx API.' + '\r\n')
    sys.exit(1);

# ------------------------------------------
# Initialize Once
# ------------------------------------------
print('Initialize = ' + str(chaseDLL.DAx22000_Initialize(C.c_int32(addr))) + '\r\n')

# ------------------------------------------
# Set Clock Rate
# ------------------------------------------
print('DAx22000_SetClkRate = ' + \
      str(chaseDLL.DAx22000_SetClkRate(C.c_int32(addr), C.c_double(1e+9))) + '\r\n')

# ------------------------------------------
# Create Waveform Array and Download  (64 samples, external trigger, loop segment once each time)
# ------------------------------------------

xpts = np.arange(64)
ypts = np.zeros(len(xpts), dtype=np.uint16)
ypts = ypts + np.ceil(2047.5 + 2047.5 * np.sin(2.0 * np.pi * xpts / (32)))
ypts = np.int_(ypts)
#print('Waveform Array' + '\n' + str(ypts) + '\n')

arr = (C.c_uint16 * len(ypts))(*ypts)

print('Array Size = ' + str(C.sizeof(arr)) + '\n\r')

# CardNum,          ChanNum,       NumPoints,     NumLoops,
chaseDLL.DAx22000_CreateSingleSegment(C.c_uint32(addr), C.c_uint32(1), C.c_uint32(64), C.c_uint32(0),
                                      C.c_uint32(2047), C.c_uint32(2047), arr, C.c_uint32(0))

chaseDLL.DAx22000_CreateSingleSegment(C.c_uint32(addr), C.c_uint32(2), C.c_uint32(64), C.c_uint32(0),
                                      C.c_uint32(2047), C.c_uint32(2047), arr, C.c_uint32(0))

# If triggering a single waveform, then NumLoops should be set to 1. Using '0' will cause
# waveform to repeat continuously after first trigger.

# ------------------------------------------
# Set MRK2, ExtTrig
# ------------------------------------------

print(str( chaseDLL.DAx22000_Place_MRK2(C.c_int32(addr), C.c_int32(1)) )  + '\r') 
print(str(chaseDLL.DAx22000_SelExtTrig(C.c_int32(addr), C.c_bool(True))) + '\r')

# ------------------------------------------
# Run/Stop Output Waveform
# ------------------------------------------

print(chaseDLL.DAx22000_Run(C.c_int32(addr), C.c_bool(True)))  # True will create (1) soft trigger.
#time.sleep(5)

#input("...")  # hit key to continue
#print(chaseDLL.DAx22000_Stop(C.c_int32(addr)))

# ------------------------------------------
# Close DAx22000 API Driver
# ------------------------------------------
#time.sleep(5)

#input("...")  # hit key to continue

#chaseDLL.DAx22000_PWR_DWN(C.c_int32(addr))

#print(chaseDLL.DAx22000_Close(C.c_int32(addr)))  # No need to call until you close master program.
# Open/Close takes 200 msec.


